==> location-1.3.4-sources.jar: com/locnavi/location/xunjimap/XJWebMapActivity.java <==
package com.locnavi.location.xunjimap;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.text.TextUtils;
import android.view.WindowManager;
import android.webkit.WebSettings;
import android.webkit.WebView;

import com.locnavi.location.R;
import com.locnavi.location.xunjimap.utils.Constants;

import org.apache.cordova.CordovaActivity;

/**
 * author:chen
 * time:2020-06-29
 * desc:
 */
public class XJWebMapActivity extends CordovaActivity {

    public static String REQUEST_ID = "id";
    public static String REQUEST_APP_KEY = "appKey";
    public static String REQUEST_USER_ID = "userId";
    public static String REQUEST_POI = "poi";
    private String url = Constants.WEB_MAP_URL;

    public static void start(Context context, String id, String appKey, String userId, String poi){
        Intent intent = new Intent(context, XJWebMapActivity.class);
        intent.putExtra(REQUEST_ID, id);
        intent.putExtra(REQUEST_APP_KEY, appKey);
        intent.putExtra(REQUEST_USER_ID, userId);
        intent.putExtra(REQUEST_POI, poi);
        intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
        context.startActivity(intent);
    }

    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        XJLocationSDK.showMap = true;
        setContentView(R.layout.activity_web_map);
        // enable Cordova apps to be started in the background
        Bundle extras = getIntent().getExtras();
        if (extras != null && extras.getBoolean("cdvStartInBackground", false)) {
            moveTaskToBack(true);
        }

        // Set by <content src="index.html" /> in config.xml
        loadUrl(launchUrl);

        String id = getIntent().getStringExtra(REQUEST_ID);
        String appKey = getIntent().getStringExtra(REQUEST_APP_KEY);
        String userId = getIntent().getStringExtra(REQUEST_USER_ID);
        String poi = getIntent().getStringExtra(REQUEST_POI);
        if(!TextUtils.isEmpty(id) && !TextUtils.isEmpty(id) && !TextUtils.isEmpty(id)){
            url += "?id=" + id;
            url += "&appKey=" + appKey;
            url += "&userId=" + userId;
        }
        if(!TextUtils.isEmpty(poi)){
            url += "&poi=" + poi;
        }
        new Handler().postDelayed(() -> {
            loadUrl("javascript:showMap(\"" + url + "\")");
            WebView webView = (WebView)appView.getEngine().getView();
            WebSettings settings = webView.getSettings();
            settings.setTextSize(WebSettings.TextSize.NORMAL);
            settings.setTextZoom(100);
        }, 2000);

    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        XJLocationSDK.showMap = false;
        getWindow().clearFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN | WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
    }



}

==> location-1.3.7-sources.jar: com/locnavi/location/xunjimap/XJWebMapActivity.java <==
package com.locnavi.location.xunjimap;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.text.TextUtils;
import android.view.WindowManager;
import android.webkit.JavascriptInterface;
import android.webkit.WebSettings;
import android.webkit.WebView;

import com.locnavi.location.R;
import com.locnavi.location.xunjimap.utils.Constants;
import com.locnavi.location.xunjimap.utils.L;

import org.apache.cordova.CordovaActivity;

/**
 * author:chen
 * time:2020-06-29
 * desc:
 */
public class XJWebMapActivity extends CordovaActivity {

    public static String REQUEST_ID = "id";
    public static String REQUEST_HOSPITAL_ID = "hospitalId";
    public static String REQUEST_APP_KEY = "appKey";
    public static String REQUEST_USER_ID = "userId";
    public static String REQUEST_POI = "poi";
    private String url = Constants.WEB_MAP_URL;

    public static void start(Context context, String id, String appKey, String userId, String poi){
        Intent intent = new Intent(context, XJWebMapActivity.class);
        intent.putExtra(REQUEST_ID, id);
        intent.putExtra(REQUEST_APP_KEY, appKey);
        intent.putExtra(REQUEST_USER_ID, userId);
        intent.putExtra(REQUEST_POI, poi);
        intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
        context.startActivity(intent);
    }

    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        XJLocationSDK.showMap = true;
        setContentView(R.layout.activity_web_map);
        // enable Cordova apps to be started in the background
        Bundle extras = getIntent().getExtras();
        if (extras != null && extras.getBoolean("cdvStartInBackground", false)) {
            moveTaskToBack(true);
        }

        // Set by <content src="index.html" /> in config.xml
        loadUrl(launchUrl);

        String id = getIntent().getStringExtra(REQUEST_ID);
        String hospitalId = getIntent().getStringExtra(REQUEST_HOSPITAL_ID);
        String appKey = getIntent().getStringExtra(REQUEST_APP_KEY);
        String userId = getIntent().getStringExtra(REQUEST_USER_ID);
        String poi = getIntent().getStringExtra(REQUEST_POI);
        if(!TextUtils.isEmpty(appKey)){
            url += "?appKey=" + appKey;
        }
        if(!TextUtils.isEmpty(id)){
            url += "&id=" + id;
        }
        if(!TextUtils.isEmpty(hospitalId)){
            url += "&hospitalId=" + hospitalId;
        }
        if(!TextUtils.isEmpty(userId)){
            url += "&userId=" + userId;
        }
        if(!TextUtils.isEmpty(poi)){
            url += "&poi=" + poi;
        }
        new Handler().postDelayed(() -> {
            loadUrl("javascript:showMap(\"" + url + "\")");
            WebView webView = (WebView)appView.getEngine().getView();
            WebSettings settings = webView.getSettings();
            settings.setTextSize(WebSettings.TextSize.NORMAL);
            settings.setTextZoom(100);
        }, 2000);

    }



    @Override
    public void onDestroy() {
        super.onDestroy();
        XJLocationSDK.showMap = false;
        getWindow().clearFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN | WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
    }



}
